@@ -95,12 +95,18 @@ FAILEDOPERATION_DCUNSUPPORTEDOPERATION = 'FailedOperation.DCUnsupportedOperation
 # 名称重复。
 FAILEDOPERATION_DUPLICATENAME = 'FailedOperation.DuplicateName'
 
+# 训练任务名称已存在，请更换名称
+FAILEDOPERATION_DUPLICATENAMETASKISCREATING = 'FailedOperation.DuplicateNameTaskIsCreating'
+
 # 数据库执行错误。
 FAILEDOPERATION_EXECDATABASEFAIL = 'FailedOperation.ExecDatabaseFail'
 
 # 标签操作失败。
 FAILEDOPERATION_EXECTAGFAIL = 'FailedOperation.ExecTagFail'
 
+# 余额不足冻结失败。
+FAILEDOPERATION_FREEZEBILLFAILED = 'FailedOperation.FreezeBillFailed'
+
 # 白名单免费配额不足。
 FAILEDOPERATION_INSUFFICIENTWHITELISTQUOTA = 'FailedOperation.InsufficientWhitelistQuota'
 
@@ -137,6 +143,9 @@ FAILEDOPERATION_QUERYMODELSBYTAGSFAILED = 'FailedOperation.QueryModelsByTagsFail
 # 查询计费价格失败。
 FAILEDOPERATION_QUERYPRICEFAILED = 'FailedOperation.QueryPriceFailed'
 
+# 查询计费项详情失败。
+FAILEDOPERATION_QUERYRESOURCESPECFAILED = 'FailedOperation.QueryResourceSpecFailed'
+
 # 查询计费项失败。
 FAILEDOPERATION_QUERYSPECSFAILED = 'FailedOperation.QuerySpecsFailed'
 
@@ -164,6 +173,15 @@ FAILEDOPERATION_UNMARSHALDATA = 'FailedOperation.UnmarshalData'
 # 内部错误。
 INTERNALERROR = 'InternalError'
 
+# 绑定标签失败
+INTERNALERROR_BINDINGTAGSFAILED = 'InternalError.BindingTagsFailed'
+
+# 创建JOB失败
+INTERNALERROR_CREATEJOBINSTANCEFAILED = 'InternalError.CreateJobInstanceFailed'
+
+# 创建TCR镜像仓库长期访问凭证失败
+INTERNALERROR_CREATETCRINSTANCETOKENFAILED = 'InternalError.CreateTcrInstanceTokenFailed'
+
 # 冻结失败。
 INTERNALERROR_FREEZEBILLFAILED = 'InternalError.FreezeBillFailed'
 
@@ -185,12 +203,18 @@ INTERNALERROR_QUERYHDFSINFOFAILED = 'InternalError.QueryHDFSInfoFailed'
 # 查询预付费资源组详情失败。
 INTERNALERROR_QUERYRESOURCEGROUPFAILED = 'InternalError.QueryResourceGroupFailed'
 
+# 查询资源套餐规格失败
+INTERNALERROR_QUERYRESOURCESPECFAILED = 'InternalError.QueryResourceSpecFailed'
+
 # 查询子网信息失败。
 INTERNALERROR_QUERYSUBNETINFOFAILED = 'InternalError.QuerySubnetInfoFailed'
 
 # 停止任务失败。
 INTERNALERROR_STOPJOBINSTANCEFAILED = 'InternalError.StopJobInstanceFailed'
 
+# 未提交状态禁止停止
+INTERNALERROR_UNSUBMITTEDSTATUSNOTALLOWSTOP = 'InternalError.UnSubmittedStatusNotAllowStop'
+
 # 参数错误。
 INVALIDPARAMETER = 'InvalidParameter'
 
@@ -209,6 +233,9 @@ INVALIDPARAMETER_VALIDATEERROR = 'InvalidParameter.ValidateError'
 # 参数取值错误。
 INVALIDPARAMETERVALUE = 'InvalidParameterValue'
 
+# AI市场公共算法版本Id不存在
+INVALIDPARAMETERVALUE_AIMARKETPUBLICALGOVERSIONNOTEXIST = 'InvalidParameterValue.AIMarketPublicAlgoVersionNotExist'
+
 # 名称不合法。
 INVALIDPARAMETERVALUE_BADNAME = 'InvalidParameterValue.BadName'
 
@@ -248,6 +275,9 @@ INVALIDPARAMETERVALUE_DUPLICATENAME = 'InvalidParameterValue.DuplicateName'
 # 训练框架对应的版本不支持，请阅读文档查看TIONE目前支持的框架和版本。
 INVALIDPARAMETERVALUE_FRAMEWORKVERSIONNOTSUPPORT = 'InvalidParameterValue.FrameworkVersionNotSupport'
 
+# 获取CFS的挂载IP失败
+INVALIDPARAMETERVALUE_GETCFSMOUNTIPFAILED = 'InvalidParameterValue.GetCFSMountIPFailed'
+
 # 训练任务镜像不存在。
 INVALIDPARAMETERVALUE_IMAGENOTFOUND = 'InvalidParameterValue.ImageNotFound'
 
@@ -260,6 +290,18 @@ INVALIDPARAMETERVALUE_LIMITEXCEEDED = 'InvalidParameterValue.LimitExceeded'
 # 操作不允许。
 INVALIDPARAMETERVALUE_NOTALLOW = 'InvalidParameterValue.NotAllow'
 
+# 分页查询limit超出限制
+INVALIDPARAMETERVALUE_PAGELIMITEXCEEDED = 'InvalidParameterValue.PageLimitExceeded'
+
+# RDMA配置不合法
+INVALIDPARAMETERVALUE_RDMACONFIGILLEGAL = 'InvalidParameterValue.RDMAConfigIllegal'
+
+# 资源配置不合法
+INVALIDPARAMETERVALUE_RESOURCECONFIGILLEGAL = 'InvalidParameterValue.ResourceConfigIllegal'
+
+# 裸金属类型资源组不支持配置输入数据
+INVALIDPARAMETERVALUE_UNSUPPORTEDDATACONFIG = 'InvalidParameterValue.UnsupportedDataConfig'
+
 # 超过配额限制。
 LIMITEXCEEDED = 'LimitExceeded'
 
@@ -272,7 +314,10 @@ OPERATIONDENIED = 'OperationDenied'
 # 余额不足，创建/更新失败。
 OPERATIONDENIED_BALANCEINSUFFICIENT = 'OperationDenied.BalanceInsufficient'
 
-# 后付费资源售罄。
+# 计费平台出错
+OPERATIONDENIED_BILLINGEXCEPTION = 'OperationDenied.BillingException'
+
+# 按量计费资源售罄。
 OPERATIONDENIED_BILLINGSTATUSRESOURCEINSUFFICIENT = 'OperationDenied.BillingStatusResourceInsufficient'
 
 # 觅影资源包余额不足，请先充值。
@@ -281,6 +326,9 @@ OPERATIONDENIED_MIYINGBALANCEINSUFFICIENT = 'OperationDenied.MIYINGBalanceInsuff
 # 网段不合法。
 OPERATIONDENIED_NETWORKCIDRILLEGAL = 'OperationDenied.NetworkCidrIllegal'
 
+# 操作不允许
+OPERATIONDENIED_NOTALLOW = 'OperationDenied.NotAllow'
+
 # 预付费资源组余量不足。
 OPERATIONDENIED_RESOURCEGROUPINSUFFICIENT = 'OperationDenied.ResourceGroupInsufficient'
 
